@@ -10,7 +10,7 @@ import ddtcv
 
 from threading import Thread
 from ctypes import windll
-from ddtank_ import stop_thread
+from ddtank import stop_thread
 
 VkKeyScanA = windll.user32.VkKeyScanA
 
@@ -137,9 +137,6 @@ class Status:
         while (time.perf_counter() - start) * 1000 < period:
             continue
 
-    def __activate(self):
-        win32api.PostMessage(self.handle, win32con.WM_SETFOCUS, 0, 0)
-
     def __click(self, pos: tuple):
         long_position = win32api.MAKELONG(*pos)
         win32api.SendMessage(self.handle, win32con.WM_LBUTTONDOWN, win32con.MK_LBUTTON, long_position)
@@ -179,6 +176,9 @@ class Status:
             return img
         self.capture = img
 
+    def activate(self):
+        win32api.PostMessage(self.handle, win32con.WM_SETFOCUS, 0, 0)
+
     def find(self, method: str = 'point', **kwargs):
         if method in ('point', 'p'):
             pos = kwargs['pos']
@@ -226,9 +226,9 @@ class Status:
                     if 'else' in kwargs.keys():
                         kwargs['else']()
                     elif 'period' in kwargs.keys():
-                        self.__delay(kwargs['period'])
+                        self.__sleep(kwargs['period'])
                     else:
-                        self.__delay(1000)
+                        self.__sleep(1000)
         elif method in ('find_image', 'fi'):
             img = kwargs['img']
             if 'part' in kwargs.keys():
@@ -251,9 +251,9 @@ class Status:
                     break
                 else:
                     if 'period' in kwargs.keys():
-                        self.__delay(kwargs['period'])
+                        self.__sleep(kwargs['period'])
                     else:
-                        self.__delay(1000)
+                        self.__sleep(1000)
 
     def press(self, key_series):
         for key in key_series:
@@ -342,7 +342,7 @@ class Status:
                 if circle_pos:
                     return circle_pos
                 else:
-                    self.__delay(100)
+                    self.__sleep(100)
 
         self.__capture()
         self.wind = read_wind()
@@ -394,7 +394,7 @@ class Status:
                 x_pos = 647
 
             win32api.PostMessage(self.handle, win32con.WM_KEYDOWN, 32, 0)
-            self.__sleep(100)
+            self.__delay(100)
             pixel = self.capture()[y_pos, x_pos]
             while True:
                 if (self.capture()[y_pos, x_pos] != pixel).any():
@@ -410,7 +410,7 @@ class Status:
             change_angle(self.angle, shot_angle[0])
             press_shot(shot_strength)
             for i in range(1, len(shot_angle)):
-                self.__sleep(800)
+                self.__delay(800)
                 change_angle(shot_angle[i-1], shot_angle[i])
 
     def move(self, move_face: str, move_period: int, reverse_face: bool = False):
